import React, { useState, useEffect, useRef } from 'react'
import CustomNav from '@/components/CustomNav'
import { useRouter } from '@tarojs/taro'
import { getShopList, getShopMoney, getAccount, getVerifiedOrder, setGetVerifiedOrder } from '@/services/shopBoss'
import { withSubscribeMessage } from '@/utils/subscribeMessage'
import SpinBox from "@/components/Spin/SpinBox";
import withLayout from '@/layouts'
import {
  TPL_MESSAGE_SHOP_PAY_SUCCESS,
  TPL_MESSAGE_SHOP_VERIFY_RESULT,
} from '@/utils/constants'
import tabList from './Shoptabbar'
import ShopKeeper from '../../components/ShopKeeper/shopKeeper'
import Sparead from '../../components/Sparead/spreadMoney'


import './spreadIndex.less'


export default withLayout((props) => {
  const { router, person } = props

  const { params } = useRouter()
  const { tab } = params || {}
  const [currentTab, setCurrentTab] = useState(0)
  const [shopList, setShopList] = useState([])
  const [shop, setShop] = useState()
  const shopId = shop?.shopId
  const [loading, setLoading] = useState(false)

  const [amountType, setAmountType] = useState('order')
  const [isVerified, setisVerified] = useState(0)
  const [shopMoney, setShopMoney] = useState([])
  const [verifiedOrder, setVerifiedOrder] = useState([])
  const listRef = useRef()

  const handleTabChange = (e) => {
    const { index } = e.detail
    index?setAmountType('commission'):setAmountType('order')
    setCurrentTab(index)
    //如果context有的话代表他滚动了   那么切换tab页就置顶
    if (listRef.current?.context) {
      listRef.current.context.scrollTo({ top: 0 })
    }
    withSubscribeMessage([TPL_MESSAGE_SHOP_PAY_SUCCESS, TPL_MESSAGE_SHOP_VERIFY_RESULT])
  }
  //商铺列表
  useEffect(() => {
    getShopList().then((res) => {
      const { shopList: list, shop: current } = res
      setShopList(list)
      setShop(current)
    })
  }, [])


  // 搜索核销手机号
  const setVer = (e) => {
    setVerifiedOrder(e.records)
  }


  const onVarified = () => {
    setisVerified(1)
  }


  const onVarifiedTwo = () => {
    setisVerified(0)
  }

  useEffect(() => {
    setLoading(true)
    if (shopId) {
      getShopMoney(shopId, amountType).then((e) => {
        setShopMoney(e)
        setLoading(false)
      }).catch(setLoading(false))
    }

  }, [amountType, shopId, currentTab])

  //店铺选择
  const handleHotelChange = (current) => {
    getShopMoney(current.shopId, amountType).then((e) => {
      setShop(current)
      getVerifiedOrder({
        isVerified: isVerified,
        pageNum: 1,
        pageSize: 99,
        shopId: current.shopId,
      }).then((res) => {
        const order = res.records
        setVerifiedOrder(order)
      })
    })
  }

  useEffect(() => {
    if (tab) {
      setCurrentTab(tab - 0)
    }
  }, [tab])

  return (
    <SpinBox loading={loading} className='page-index'>
      <view className='index-navbar'>
        <CustomNav title={shop?.shopName} />
      </view>
      <view className='index-container'>
        {currentTab === 0 && <ShopKeeper isVerified={isVerified} shopId={shopId} amountType={amountType} setVer={setVer} onVarifiedTwo={onVarifiedTwo} onVarified={onVarified} verifiedOrder={verifiedOrder} shopList={shopList} shop={shop} onHotelChange={handleHotelChange} shopMoney={shopMoney} />
        }
        {currentTab === 1 && <Sparead shopList={shopList} shop={shop} verifiedOrder={verifiedOrder} onHotelChange={handleHotelChange} shopMoney={shopMoney} />}
      </view>
      <view className='index-tabbar'>
        <mp-tabbar extClass='custom-tabbar' current={currentTab} list={tabList} onChange={handleTabChange}></mp-tabbar>
      </view>
    </SpinBox>

  )

})
